@@ -39,7 +39,8 @@ pub struct TransactionCreateEvent {
     #[index]
     pub transaction: Pubkey,
     pub proposer: Pubkey,
-    pub instruction: Instruction,
+    /// Instructions associated with the [Transaction].
+    pub instructions: Vec<TXInstruction>,
     pub eta: i64,
     pub timestamp: i64,
 }
@@ -55,6 +56,17 @@ pub struct TransactionApproveEvent {
     pub timestamp: i64,
 }
 
+/// Emitted when a [Transaction] is unapproved.
+#[event]
+pub struct TransactionUnapproveEvent {
+    #[index]
+    pub smart_wallet: Pubkey,
+    #[index]
+    pub transaction: Pubkey,
+    pub owner: Pubkey,
+    pub timestamp: i64,
+}
+
 /// Emitted when a [Transaction] is executed.
 #[event]
 pub struct TransactionExecuteEvent {
